// synopsys translate_off
`timescale 1 ps / 1 ps
// synopsys translate_on

module keim08_top(
	input	wire			clk,        //50MHz
	input	wire			reset_n,
    
	//Memory I/F
	output	wire	[21:0]	mem_a,
	inout	wire	[15:0]	mem_dq,
	output	wire			sdram_clk,
	output	wire			sdram_ras_n,
	output	wire			sdram_we_n,
	output	wire			sdram_cs_n,
	output	wire	[ 1:0]	sdram_ba,
	output	wire	[ 1:0]	sdram_dqm,
	output	wire			sdram_cas_n,
	output	wire			sdram_cke,
	output	wire			flash_ce_n,
	output	wire			flash_we_n,
	output	wire			flash_oe_n,
	output	wire			flash_rst_n,
  
	//General Port
	inout	wire	[15:0]	pa_pin,
	inout	wire	[15:0]	pb_pin,
	inout	wire	[15:0]	pc_pin,
	inout	wire	[15:0]	pd_pin,
	inout	wire	[ 1:0]	pe_pin
    
);
    
//---------------------- internal signals ----------------------
	wire				pll_0_locked;
	wire				ins_reset_n;
    
//user peripherals
	wire				uart_0_rxd;		//uart_0_rxd
	wire				uart_0_txd;		//uart_0_txd
	
	wire	[1:0]		pio_led_external_connection;		//pio_led_external_connection
    
//---------------------- logic description ----------------------
    
//---------------------- generate delay reset ----------------------

//---------------------- instanse reset controller ----------------------
	reset_cont	reset_cont(
		.clk			(clk),
		.reset_n		(reset_n),
		.pll_locked		(pll_0_locked),
		.ins_reset_n	(ins_reset_n)
	);
    
//---------------------- core instanse ----------------------
    
	keim08core u0 (
		.altpll_areset_export                   (1'b0),
		.altpll_c1_clk                          (sdram_clk),
		.altpll_locked_export                   (pll_0_locked),
		.clk_clk                                (clk),
		.emif_flash_tcm_reset_n_out             (flash_rst_n),
		.emif_sdram_sdram_cke                   (sdram_cke),
		.emif_sdram_sdram_cas_n                 (sdram_cas_n),
		.emif_dq                                (mem_dq),
		.emif_sdram_sdram_we_n                  (sdram_we_n),
		.emif_sdram_sdram_cs_n                  (sdram_cs_n),
		.emif_flash_tcm_chipselect_n_out        (flash_ce_n),
		.emif_addr                              (mem_a),
		.emif_sdram_sdram_ba                    (sdram_ba),
		.emif_sdram_sdram_dqm                   (sdram_dqm),
		.emif_sdram_sdram_ras_n                 (sdram_ras_n),
		.emif_flash_tcm_write_n_out             (flash_we_n),
		.emif_flash_tcm_read_n_out              (flash_oe_n),
		.reset_reset_n                          (ins_reset_n),
		.uart_0_rxd                             (uart_0_rxd),
		.uart_0_txd                             (uart_0_txd),
		.pio_led_external_connection_export     (pio_led_external_connection)
	);


//////////////////////////////////
	 
//---------------------- port assinment ----------------------
	assign pa_pin[0] = uart_0_txd;
	assign uart_0_rxd = pa_pin[1];
	assign pe_pin[0] = ~pio_led_external_connection[0];
	assign pe_pin[1] = ~pio_led_external_connection[1];
    
endmodule
