// synopsys translate_off
`timescale 1 ps / 1 ps
// synopsys translate_on

module reset_cont(
	input		wire	clk,        // 50MHz
	input		wire	reset_n,    // system reset
	input		wire	pll_locked, // H: locked, L: unlocked
//	output	wire	ins_reset_n // inside reset
	output	reg	ins_reset_n
 // inside reset
);

//---------------------- internal signals ----------------------
	parameter			CNT_WIDTH = 8;
	reg	[CNT_WIDTH-1:0]	init_cnt;

//---------------------- logic description ----------------------
	always @(posedge clk or negedge reset_n) begin
		if(!reset_n)
			init_cnt <= 0;
		else if(!pll_locked)
			init_cnt <= 0;
		else if(!init_cnt[CNT_WIDTH-1])
			init_cnt <= init_cnt + 1'b1;
	end

//	assign ins_reset_n = init_cnt[CNT_WIDTH-1];
////// About a RESETn signal with much Fanout,
////// it is single conversion to signals at a flip-flop. 
////// Since this signal is asynchronous and
////// it is satisfactory, even if it shifts 1 clock cycle.
	always @(posedge clk or negedge reset_n) begin
		if(!reset_n)
			ins_reset_n <= 1'b0;
		else case (ins_reset_n)
			1'b0: if (init_cnt[CNT_WIDTH-1])
				ins_reset_n <= 1'b1;
			1'b1:
				ins_reset_n <= ins_reset_n ;
		endcase
		end
    
endmodule
